.. _users_guide:

###############################
User's guide -- selected topics
###############################

Welcome to the ODL user's guide.
This section contains in-depth explanations of selected topics in ODL.
It is intended to familiarize you with important concepts that can be hard to infer from the API documentation and the overall introduction only.

.. toctree::
    :maxdepth: 1

    operator_guide
    linearspace_guide
    numpy_guide
    vectorization_guide
    geometry_guide
    functional_guide
    proximal_lang_guide
    pdhg_guide
    migrate1.0_guide
